Learn R Programming

legocolors (version 0.2.0)

legopals: Lego color palettes.

Description

A named list of nine Lego color palettes based on legocolors$material. Because these palettes represent a meaningful segmentation of Lego material types, they are not intended to represent useful color palettes for mapping data values to colors.

Usage

legopals

Arguments

Format

A named list of nine color palettes.